ElasticNet

Struct ElasticNet 

pub struct ElasticNet<TX: FloatNumber + RealNumber, TY: Number, X: Array2<TX>, Y: Array1<TY>> { /* private fields */ }
Elastic net

Implementations

Source

impl<TX: FloatNumber + RealNumber, TY: Number, X: Array2<TX>, Y: Array1<TY>> ElasticNet<TX, TY, X, Y>

pub fn fit( x: &X, y: &Y, parameters: ElasticNetParameters, ) -> Result<ElasticNet<TX, TY, X, Y>, Failed>

Fits elastic net regression to your data.

  • x - NxM matrix with N observations and M features in each observation.
  • y - target values
  • parameters - other parameters, use Default::default() to set parameters to default values.
pub fn predict(&self, x: &X) -> Result<Y, Failed>

Predict target values from x

  • x - KxM data where K is number of observations and M is number of features.
pub fn coefficients(&self) -> &X

Get estimates regression coefficients

pub fn intercept(&self) -> &TX

Get estimate of intercept