SVR

Struct SVR 

pub struct SVR<'a, T: Number + FloatNumber + PartialOrd, X: Array2<T>, Y: Array1<T>> { /* private fields */ }
Epsilon-Support Vector Regression

Implementations

Source

impl<'a, T: Number + FloatNumber + PartialOrd, X: Array2<T>, Y: Array1<T>> SVR<'a, T, X, Y>

pub fn fit( x: &'a X, y: &'a Y, parameters: &'a SVRParameters<T>, ) -> Result<SVR<'a, T, X, Y>, Failed>

Fits SVR to your data.

  • x - NxM matrix with N observations and M features in each observation.
  • y - target values
  • kernel - the kernel function
  • parameters - optional parameters, use Default::default() to set parameters to default values.
pub fn predict(&self, x: &'a X) -> Result<Vec<T>, Failed>

Predict target values from x

  • x - KxM data where K is number of observations and M is number of features.