pub trait MutArray<T: Debug + Display + Copy + Sized, S>: Array<T, S> {
Show 15 methods
// Required methods
fn set(&mut self, pos: S, x: T);
fn iterator_mut<'b>(
&'b mut self,
axis: u8,
) -> Box<dyn Iterator<Item = &'b mut T> + 'b>;
// Provided methods
fn swap(&mut self, a: S, b: S)
where S: Copy { ... }
fn div_element_mut(&mut self, pos: S, x: T)
where T: Number,
S: Copy { ... }
fn mul_element_mut(&mut self, pos: S, x: T)
where T: Number,
S: Copy { ... }
fn add_element_mut(&mut self, pos: S, x: T)
where T: Number,
S: Copy { ... }
fn sub_element_mut(&mut self, pos: S, x: T)
where T: Number,
S: Copy { ... }
fn sub_scalar_mut(&mut self, x: T)
where T: Number { ... }
fn add_scalar_mut(&mut self, x: T)
where T: Number { ... }
fn mul_scalar_mut(&mut self, x: T)
where T: Number { ... }
fn div_scalar_mut(&mut self, x: T)
where T: Number { ... }
fn add_mut(&mut self, other: &dyn Array<T, S>)
where T: Number,
S: Eq { ... }
fn sub_mut(&mut self, other: &dyn Array<T, S>)
where T: Number,
S: Eq { ... }
fn mul_mut(&mut self, other: &dyn Array<T, S>)
where T: Number,
S: Eq { ... }
fn div_mut(&mut self, other: &dyn Array<T, S>)
where T: Number,
S: Eq { ... }
}Expand description
Abstract methods for mutable Array
Required Methods
Provided Methods
Sourcefn div_element_mut(&mut self, pos: S, x: T)
fn div_element_mut(&mut self, pos: S, x: T)
divide element by a given value
Sourcefn mul_element_mut(&mut self, pos: S, x: T)
fn mul_element_mut(&mut self, pos: S, x: T)
multiply element for a given value
Sourcefn add_element_mut(&mut self, pos: S, x: T)
fn add_element_mut(&mut self, pos: S, x: T)
add a given value to an element
Sourcefn sub_element_mut(&mut self, pos: S, x: T)
fn sub_element_mut(&mut self, pos: S, x: T)
subtract a given value to an element
Sourcefn sub_scalar_mut(&mut self, x: T)where
T: Number,
fn sub_scalar_mut(&mut self, x: T)where
T: Number,
subtract a given value to all the elements
Sourcefn add_scalar_mut(&mut self, x: T)where
T: Number,
fn add_scalar_mut(&mut self, x: T)where
T: Number,
add a given value to all the elements
Sourcefn mul_scalar_mut(&mut self, x: T)where
T: Number,
fn mul_scalar_mut(&mut self, x: T)where
T: Number,
multiply a given value to all the elements
Sourcefn div_scalar_mut(&mut self, x: T)where
T: Number,
fn div_scalar_mut(&mut self, x: T)where
T: Number,
divide a given value to all the elements
Sourcefn add_mut(&mut self, other: &dyn Array<T, S>)
fn add_mut(&mut self, other: &dyn Array<T, S>)
add values from another array to the values of initial array
Sourcefn sub_mut(&mut self, other: &dyn Array<T, S>)
fn sub_mut(&mut self, other: &dyn Array<T, S>)
subtract values from another array to the values of initial array