pub fn train_test_split<TX: Debug + Display + Copy + Sized, TY: Debug + Display + Copy + Sized, X: Array2<TX>, Y: Array1<TY>>(
x: &X,
y: &Y,
test_size: f32,
shuffle: bool,
seed: Option<u64>,
) -> (X, X, Y, Y)Expand description
Splits data into 2 disjoint datasets.
x- features, matrix of size NxM where N is number of samples and M is number of attributes.y- target values, should be of size Ntest_size, (0, 1] - the proportion of the dataset to include in the test split.shuffle, - whether or not to shuffle the data before splitting